==> haskell-stringsearch-0.3.6.6-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stringsearch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stringsearch
version:              0.3.6.6
visibility:           public
id:                   stringsearch-0.3.6.6-AM6x09WxW62EXkEavMQG63
key:                  stringsearch-0.3.6.6-AM6x09WxW62EXkEavMQG63
license:              BSD-3-Clause
copyright:
    (c) 2007-2011
    Daniel Fischer, Chris Kuklewicz, Justin Bailey

maintainer:           daniel.is.fischer@googlemail.com
author:               Daniel Fischer, Chris Kuklewicz, Justin Bailey
homepage:             https://bitbucket.org/dafis/stringsearch
synopsis:             Fast searching, splitting and replacing of ByteStrings
description:
    This package provides several functions to quickly
    search for substrings in strict or lazy ByteStrings.
    It also provides functions for breaking or splitting
    on substrings and replacing all occurrences of a
    substring (the first in case of overlaps) with another.
    GHC before 6.10 are no longer supported, other compilers
    only if they support BangPatterns. If you need it to
    work with other compilers, send a feature request.

category:             Text, Search
abi:                  b3b4835da20e1ebbe6496b81ca5b71e4
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Search Data.ByteString.Lazy.Search.DFA
    Data.ByteString.Lazy.Search.KMP
    Data.ByteString.Lazy.Search.KarpRabin Data.ByteString.Search
    Data.ByteString.Search.BoyerMoore Data.ByteString.Search.DFA
    Data.ByteString.Search.KMP Data.ByteString.Search.KarpRabin
    Data.ByteString.Search.KnuthMorrisPratt
    Data.ByteString.Search.Substitution

hidden-modules:
    Data.ByteString.Search.Internal.BoyerMoore
    Data.ByteString.Search.Internal.KnuthMorrisPratt
    Data.ByteString.Search.Internal.Utils
    Data.ByteString.Lazy.Search.Internal.BoyerMoore

import-dirs:          /usr/lib/ghc-9.0.1/site-local/stringsearch-0.3.6.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/stringsearch-0.3.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/stringsearch-0.3.6.6
hs-libraries:         HSstringsearch-0.3.6.6-AM6x09WxW62EXkEavMQG63
depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1

haddock-interfaces:
    /usr/share/doc/haskell-stringsearch/html/stringsearch.haddock

haddock-html:         /usr/share/doc/haskell-stringsearch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stringsearch-0.3.6.6-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stringsearch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stringsearch
version:              0.3.6.6
visibility:           public
id:                   stringsearch-0.3.6.6-BXrkU76S0Kr98hWC20gM4F
key:                  stringsearch-0.3.6.6-BXrkU76S0Kr98hWC20gM4F
license:              BSD-3-Clause
copyright:
    (c) 2007-2011
    Daniel Fischer, Chris Kuklewicz, Justin Bailey

maintainer:           daniel.is.fischer@googlemail.com
author:               Daniel Fischer, Chris Kuklewicz, Justin Bailey
homepage:             https://bitbucket.org/dafis/stringsearch
synopsis:             Fast searching, splitting and replacing of ByteStrings
description:
    This package provides several functions to quickly
    search for substrings in strict or lazy ByteStrings.
    It also provides functions for breaking or splitting
    on substrings and replacing all occurrences of a
    substring (the first in case of overlaps) with another.
    GHC before 6.10 are no longer supported, other compilers
    only if they support BangPatterns. If you need it to
    work with other compilers, send a feature request.

category:             Text, Search
abi:                  d8f33c63d760123bb5d753b36147d149
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Search Data.ByteString.Lazy.Search.DFA
    Data.ByteString.Lazy.Search.KMP
    Data.ByteString.Lazy.Search.KarpRabin Data.ByteString.Search
    Data.ByteString.Search.BoyerMoore Data.ByteString.Search.DFA
    Data.ByteString.Search.KMP Data.ByteString.Search.KarpRabin
    Data.ByteString.Search.KnuthMorrisPratt
    Data.ByteString.Search.Substitution

hidden-modules:
    Data.ByteString.Search.Internal.BoyerMoore
    Data.ByteString.Search.Internal.KnuthMorrisPratt
    Data.ByteString.Search.Internal.Utils
    Data.ByteString.Lazy.Search.Internal.BoyerMoore

import-dirs:          /usr/lib/ghc-9.0.2/site-local/stringsearch-0.3.6.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/stringsearch-0.3.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/stringsearch-0.3.6.6
hs-libraries:         HSstringsearch-0.3.6.6-BXrkU76S0Kr98hWC20gM4F
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1

haddock-interfaces:
    /usr/share/doc/haskell-stringsearch/html/stringsearch.haddock

haddock-html:         /usr/share/doc/haskell-stringsearch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
